"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

This is the POC for metric-backend service that supports
1. receiving usage reports from pipeline-backend and model-backend clients
2. uploading usage to InfluxDB
3. uploading usage to Stripe
4. responding usage/price enquiries from clients
"""
import abc
import collections.abc
import core.metric.v1beta.metric_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class PipelineServiceStub:
    """Services related to pipeline trigger records
    Service for get pipeline information
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetPipelines: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelinesRequest,
        core.metric.v1beta.metric_pb2.GetPipelinesResponse,
    ]
    """Get pipeline info"""
    ReportPipelineTrigger: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportPipelineTriggerRequest,
        core.metric.v1beta.metric_pb2.ReportPipelineTriggerResponse,
    ]
    """Services for reporting usages

    For pipeline-backend clients to report a pipeline trigger record
    """
    ReportPipelineTriggers: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportPipelineTriggersRequest,
        core.metric.v1beta.metric_pb2.ReportPipelineTriggersResponse,
    ]
    """For pipeline-backend clients to report pipeline trigger records"""
    GetPipelineTriggerRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsResponse,
    ]
    """Services for querying usages

    Get pipeline trigger records
    """
    GetBulkPipelineTriggerRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsResponse,
    ]
    """Get pipeline trigger records in bulk"""
    GetCumulativePipelineTriggerRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsResponse,
    ]
    """Get cumulative pipeline trigger records"""
    GetBulkCumulativePipelineTriggerRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsResponse,
    ]
    """Get cumulative pipeline trigger records in bulk"""
    GetPipelineTriggerSummary: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryResponse,
    ]
    """Get pipeline trigger summary"""
    GetBulkPipelineTriggerSummaries: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesResponse,
    ]
    """Get pipeline trigger summary in bulk"""
    GetPipelineTriggerPrice: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceResponse,
    ]
    """Services for querying prices

    Get pipeline trigger price
    """
    GetBulkPipelineTriggerPrice: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceResponse,
    ]
    """Get pipeline trigger price in bulk"""

class PipelineServiceAsyncStub:
    """Services related to pipeline trigger records
    Service for get pipeline information
    """

    GetPipelines: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelinesRequest,
        core.metric.v1beta.metric_pb2.GetPipelinesResponse,
    ]
    """Get pipeline info"""
    ReportPipelineTrigger: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportPipelineTriggerRequest,
        core.metric.v1beta.metric_pb2.ReportPipelineTriggerResponse,
    ]
    """Services for reporting usages

    For pipeline-backend clients to report a pipeline trigger record
    """
    ReportPipelineTriggers: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportPipelineTriggersRequest,
        core.metric.v1beta.metric_pb2.ReportPipelineTriggersResponse,
    ]
    """For pipeline-backend clients to report pipeline trigger records"""
    GetPipelineTriggerRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsResponse,
    ]
    """Services for querying usages

    Get pipeline trigger records
    """
    GetBulkPipelineTriggerRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsResponse,
    ]
    """Get pipeline trigger records in bulk"""
    GetCumulativePipelineTriggerRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsResponse,
    ]
    """Get cumulative pipeline trigger records"""
    GetBulkCumulativePipelineTriggerRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsResponse,
    ]
    """Get cumulative pipeline trigger records in bulk"""
    GetPipelineTriggerSummary: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryResponse,
    ]
    """Get pipeline trigger summary"""
    GetBulkPipelineTriggerSummaries: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesResponse,
    ]
    """Get pipeline trigger summary in bulk"""
    GetPipelineTriggerPrice: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceRequest,
        core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceResponse,
    ]
    """Services for querying prices

    Get pipeline trigger price
    """
    GetBulkPipelineTriggerPrice: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceRequest,
        core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceResponse,
    ]
    """Get pipeline trigger price in bulk"""

class PipelineServiceServicer(metaclass=abc.ABCMeta):
    """Services related to pipeline trigger records
    Service for get pipeline information
    """

    @abc.abstractmethod
    def GetPipelines(
        self,
        request: core.metric.v1beta.metric_pb2.GetPipelinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetPipelinesResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetPipelinesResponse]]:
        """Get pipeline info"""
    @abc.abstractmethod
    def ReportPipelineTrigger(
        self,
        request: core.metric.v1beta.metric_pb2.ReportPipelineTriggerRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.ReportPipelineTriggerResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.ReportPipelineTriggerResponse]]:
        """Services for reporting usages

        For pipeline-backend clients to report a pipeline trigger record
        """
    @abc.abstractmethod
    def ReportPipelineTriggers(
        self,
        request: core.metric.v1beta.metric_pb2.ReportPipelineTriggersRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.ReportPipelineTriggersResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.ReportPipelineTriggersResponse]]:
        """For pipeline-backend clients to report pipeline trigger records"""
    @abc.abstractmethod
    def GetPipelineTriggerRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetPipelineTriggerRecordsResponse]]:
        """Services for querying usages

        Get pipeline trigger records
        """
    @abc.abstractmethod
    def GetBulkPipelineTriggerRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerRecordsResponse]]:
        """Get pipeline trigger records in bulk"""
    @abc.abstractmethod
    def GetCumulativePipelineTriggerRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetCumulativePipelineTriggerRecordsResponse]]:
        """Get cumulative pipeline trigger records"""
    @abc.abstractmethod
    def GetBulkCumulativePipelineTriggerRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkCumulativePipelineTriggerRecordsResponse]]:
        """Get cumulative pipeline trigger records in bulk"""
    @abc.abstractmethod
    def GetPipelineTriggerSummary(
        self,
        request: core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetPipelineTriggerSummaryResponse]]:
        """Get pipeline trigger summary"""
    @abc.abstractmethod
    def GetBulkPipelineTriggerSummaries(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerSummariesResponse]]:
        """Get pipeline trigger summary in bulk"""
    @abc.abstractmethod
    def GetPipelineTriggerPrice(
        self,
        request: core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetPipelineTriggerPriceResponse]]:
        """Services for querying prices

        Get pipeline trigger price
        """
    @abc.abstractmethod
    def GetBulkPipelineTriggerPrice(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkPipelineTriggerPriceResponse]]:
        """Get pipeline trigger price in bulk"""

def add_PipelineServiceServicer_to_server(servicer: PipelineServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class ModelServiceStub:
    """Services related to model online records
    Service for get model information
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetModels: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelsRequest,
        core.metric.v1beta.metric_pb2.GetModelsResponse,
    ]
    """Get Model info"""
    ReportModelOnline: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportModelOnlineRequest,
        core.metric.v1beta.metric_pb2.ReportModelOnlineResponse,
    ]
    """Services for reporting usages

    For model-backend clients to report a model online record
    """
    ReportModelOnlines: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportModelOnlinesRequest,
        core.metric.v1beta.metric_pb2.ReportModelOnlinesResponse,
    ]
    """For model-backend clients to report moel online records"""
    GetModelOnlineRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlineRecordsResponse,
    ]
    """Services for querying usages

    Get model online records
    """
    GetBulkModelOnlineRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsResponse,
    ]
    """Get model online records in bulk"""
    GetCumulativeModelOnlineRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsResponse,
    ]
    """Get cumulative model online records"""
    GetBulkCumulativeModelOnlineRecords: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsResponse,
    ]
    """Get cumulative model online records in bulk"""
    GetModelOnlineSummary: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlineSummaryRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlineSummaryResponse,
    ]
    """Get model online summary"""
    GetBulkModelOnlineSummary: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryResponse,
    ]
    """Get model online summary in bulk"""
    GetModelOnlinePrice: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlinePriceRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlinePriceResponse,
    ]
    """Services for querying prices

    Get model online price
    """
    GetBulkModelOnlinePrice: grpc.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceResponse,
    ]
    """Get model online price in bulk"""

class ModelServiceAsyncStub:
    """Services related to model online records
    Service for get model information
    """

    GetModels: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelsRequest,
        core.metric.v1beta.metric_pb2.GetModelsResponse,
    ]
    """Get Model info"""
    ReportModelOnline: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportModelOnlineRequest,
        core.metric.v1beta.metric_pb2.ReportModelOnlineResponse,
    ]
    """Services for reporting usages

    For model-backend clients to report a model online record
    """
    ReportModelOnlines: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.ReportModelOnlinesRequest,
        core.metric.v1beta.metric_pb2.ReportModelOnlinesResponse,
    ]
    """For model-backend clients to report moel online records"""
    GetModelOnlineRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlineRecordsResponse,
    ]
    """Services for querying usages

    Get model online records
    """
    GetBulkModelOnlineRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsResponse,
    ]
    """Get model online records in bulk"""
    GetCumulativeModelOnlineRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsResponse,
    ]
    """Get cumulative model online records"""
    GetBulkCumulativeModelOnlineRecords: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsRequest,
        core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsResponse,
    ]
    """Get cumulative model online records in bulk"""
    GetModelOnlineSummary: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlineSummaryRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlineSummaryResponse,
    ]
    """Get model online summary"""
    GetBulkModelOnlineSummary: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryResponse,
    ]
    """Get model online summary in bulk"""
    GetModelOnlinePrice: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetModelOnlinePriceRequest,
        core.metric.v1beta.metric_pb2.GetModelOnlinePriceResponse,
    ]
    """Services for querying prices

    Get model online price
    """
    GetBulkModelOnlinePrice: grpc.aio.UnaryUnaryMultiCallable[
        core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceRequest,
        core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceResponse,
    ]
    """Get model online price in bulk"""

class ModelServiceServicer(metaclass=abc.ABCMeta):
    """Services related to model online records
    Service for get model information
    """

    @abc.abstractmethod
    def GetModels(
        self,
        request: core.metric.v1beta.metric_pb2.GetModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetModelsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetModelsResponse]]:
        """Get Model info"""
    @abc.abstractmethod
    def ReportModelOnline(
        self,
        request: core.metric.v1beta.metric_pb2.ReportModelOnlineRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.ReportModelOnlineResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.ReportModelOnlineResponse]]:
        """Services for reporting usages

        For model-backend clients to report a model online record
        """
    @abc.abstractmethod
    def ReportModelOnlines(
        self,
        request: core.metric.v1beta.metric_pb2.ReportModelOnlinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.ReportModelOnlinesResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.ReportModelOnlinesResponse]]:
        """For model-backend clients to report moel online records"""
    @abc.abstractmethod
    def GetModelOnlineRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetModelOnlineRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetModelOnlineRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetModelOnlineRecordsResponse]]:
        """Services for querying usages

        Get model online records
        """
    @abc.abstractmethod
    def GetBulkModelOnlineRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkModelOnlineRecordsResponse]]:
        """Get model online records in bulk"""
    @abc.abstractmethod
    def GetCumulativeModelOnlineRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetCumulativeModelOnlineRecordsResponse]]:
        """Get cumulative model online records"""
    @abc.abstractmethod
    def GetBulkCumulativeModelOnlineRecords(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkCumulativeModelOnlineRecordsResponse]]:
        """Get cumulative model online records in bulk"""
    @abc.abstractmethod
    def GetModelOnlineSummary(
        self,
        request: core.metric.v1beta.metric_pb2.GetModelOnlineSummaryRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetModelOnlineSummaryResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetModelOnlineSummaryResponse]]:
        """Get model online summary"""
    @abc.abstractmethod
    def GetBulkModelOnlineSummary(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkModelOnlineSummaryResponse]]:
        """Get model online summary in bulk"""
    @abc.abstractmethod
    def GetModelOnlinePrice(
        self,
        request: core.metric.v1beta.metric_pb2.GetModelOnlinePriceRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetModelOnlinePriceResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetModelOnlinePriceResponse]]:
        """Services for querying prices

        Get model online price
        """
    @abc.abstractmethod
    def GetBulkModelOnlinePrice(
        self,
        request: core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceResponse, collections.abc.Awaitable[core.metric.v1beta.metric_pb2.GetBulkModelOnlinePriceResponse]]:
        """Get model online price in bulk"""

def add_ModelServiceServicer_to_server(servicer: ModelServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from instill.clients.client import (
    InstillClient,
    init_artifact_client,
    init_core_client,
    init_mgmt_client,
    init_model_client,
    init_pipeline_client,
)
from instill.clients.mgmt import MgmtClient
from instill.clients.model import ModelClient
from instill.clients.pipeline import PipelineClient



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BoundingBox(google.protobuf.message.Message):
    """BoundingBox represents a frame in an image that can be drawn when detecting
    patterns in objects.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    top: builtins.float
    """Top Y-axis."""
    left: builtins.float
    """Left X-axis."""
    width: builtins.float
    """Width."""
    height: builtins.float
    """Height."""
    def __init__(
        self,
        *,
        top: builtins.float = ...,
        left: builtins.float = ...,
        width: builtins.float = ...,
        height: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "left", b"left", "top", b"top", "width", b"width"]) -> None: ...

global___BoundingBox = BoundingBox

@typing_extensions.final
class PromptImage(google.protobuf.message.Message):
    """PromptImage is an image input for model inference."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_IMAGE_URL_FIELD_NUMBER: builtins.int
    PROMPT_IMAGE_BASE64_FIELD_NUMBER: builtins.int
    prompt_image_url: builtins.str
    """Image URL."""
    prompt_image_base64: builtins.str
    """Base64-encoded image."""
    def __init__(
        self,
        *,
        prompt_image_url: builtins.str = ...,
        prompt_image_base64: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["prompt_image_url", "prompt_image_base64"] | None: ...

global___PromptImage = PromptImage

@typing_extensions.final
class ImageContent(google.protobuf.message.Message):
    """ImageContent holds an image with some details in plain text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    DETAIL_FIELD_NUMBER: builtins.int
    @property
    def image_url(self) -> global___PromptImage:
        """Image as URL or base64 code.

        NOTE: the `image_url` name comes from a convention from OpenAI, it doesn't
        determine the format of the image.
        """
    detail: builtins.str
    """Additional information."""
    def __init__(
        self,
        *,
        image_url: global___PromptImage | None = ...,
        detail: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_detail", b"_detail", "detail", b"detail", "image_url", b"image_url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_detail", b"_detail", "detail", b"detail", "image_url", b"image_url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_detail", b"_detail"]) -> typing_extensions.Literal["detail"] | None: ...

global___ImageContent = ImageContent

@typing_extensions.final
class MessageContent(google.protobuf.message.Message):
    """MessageContent is a message in a chat history message, used in text
    generation models.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Content type."""
    @property
    def image_url(self) -> global___ImageContent:
        """Image content.

        NOTE: the `image_url` name comes from a convention from OpenAI, it doesn't
        determine the format of the image.
        """
    text: builtins.str
    """Text content."""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        image_url: global___ImageContent | None = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "image_url", b"image_url", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "image_url", b"image_url", "text", b"text", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["image_url", "text"] | None: ...

global___MessageContent = MessageContent

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """Message is used in chat history in text generation models."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    role: builtins.str
    """The Role of a message, e.g. `system`, `user`, etc. Defines the way the model answers questions."""
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageContent]:
        """Message content."""
    def __init__(
        self,
        *,
        role: builtins.str = ...,
        content: collections.abc.Iterable[global___MessageContent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "role", b"role"]) -> None: ...

global___Message = Message

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    """Permission defines how a pipeline can be used."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_TRIGGER_FIELD_NUMBER: builtins.int
    can_edit: builtins.bool
    """Defines whether the pipeline can be modified."""
    can_trigger: builtins.bool
    """Defines whether the pipeline can be executed."""
    def __init__(
        self,
        *,
        can_edit: builtins.bool = ...,
        can_trigger: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_edit", b"can_edit", "can_trigger", b"can_trigger"]) -> None: ...

global___Permission = Permission



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/healthcheck/v1beta/healthcheck.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+common/healthcheck/v1beta/healthcheck.proto\x12\x19\x63ommon.healthcheck.v1beta\x1a\x1fgoogle/api/field_behavior.proto\"D\n\x12HealthCheckRequest\x12\"\n\x07service\x18\x01 \x01(\tB\x03\xe0\x41\x01H\x00R\x07service\x88\x01\x01\x42\n\n\x08_service\"\xd8\x01\n\x13HealthCheckResponse\x12T\n\x06status\x18\x01 \x01(\x0e\x32<.common.healthcheck.v1beta.HealthCheckResponse.ServingStatusR\x06status\"k\n\rServingStatus\x12\x1e\n\x1aSERVING_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERVING_STATUS_SERVING\x10\x01\x12\x1e\n\x1aSERVING_STATUS_NOT_SERVING\x10\x02\x42\x86\x02\n\x1d\x63om.common.healthcheck.v1betaB\x10HealthcheckProtoP\x01ZMgithub.com/instill-ai/protogen-go/common/healthcheck/v1beta;healthcheckv1beta\xa2\x02\x03\x43HX\xaa\x02\x19\x43ommon.Healthcheck.V1beta\xca\x02\x19\x43ommon\\Healthcheck\\V1beta\xe2\x02%Common\\Healthcheck\\V1beta\\GPBMetadata\xea\x02\x1b\x43ommon::Healthcheck::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.healthcheck.v1beta.healthcheck_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.common.healthcheck.v1betaB\020HealthcheckProtoP\001ZMgithub.com/instill-ai/protogen-go/common/healthcheck/v1beta;healthcheckv1beta\242\002\003CHX\252\002\031Common.Healthcheck.V1beta\312\002\031Common\\Healthcheck\\V1beta\342\002%Common\\Healthcheck\\V1beta\\GPBMetadata\352\002\033Common::Healthcheck::V1beta'
  _HEALTHCHECKREQUEST.fields_by_name['service']._options = None
  _HEALTHCHECKREQUEST.fields_by_name['service']._serialized_options = b'\340A\001'
  _globals['_HEALTHCHECKREQUEST']._serialized_start=107
  _globals['_HEALTHCHECKREQUEST']._serialized_end=175
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=178
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=394
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_start=287
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_end=394
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import app.app.v1alpha.app_pb2
import app.app.v1alpha.conversation_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class AppPublicServiceStub:
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.LivenessRequest,
        app.app.v1alpha.app_pb2.LivenessResponse,
    ]
    """Check if the app server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.ReadinessRequest,
        app.app.v1alpha.app_pb2.ReadinessResponse,
    ]
    """Check if the app server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateApp: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.CreateAppRequest,
        app.app.v1alpha.app_pb2.CreateAppResponse,
    ]
    """Create a app"""
    ListApps: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.ListAppsRequest,
        app.app.v1alpha.app_pb2.ListAppsResponse,
    ]
    """List all apps info"""
    UpdateApp: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.UpdateAppRequest,
        app.app.v1alpha.app_pb2.UpdateAppResponse,
    ]
    """Update a app info"""
    DeleteApp: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.DeleteAppRequest,
        app.app.v1alpha.app_pb2.DeleteAppResponse,
    ]
    """Delete a app"""
    CreateConversation: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.CreateConversationRequest,
        app.app.v1alpha.conversation_pb2.CreateConversationResponse,
    ]
    """Create a Conversation"""
    ListConversations: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ListConversationsRequest,
        app.app.v1alpha.conversation_pb2.ListConversationsResponse,
    ]
    """List conversations"""
    UpdateConversation: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.UpdateConversationRequest,
        app.app.v1alpha.conversation_pb2.UpdateConversationResponse,
    ]
    """Update a conversation"""
    DeleteConversation: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.DeleteConversationRequest,
        app.app.v1alpha.conversation_pb2.DeleteConversationResponse,
    ]
    """Delete a conversation"""
    CreateMessage: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.CreateMessageRequest,
        app.app.v1alpha.conversation_pb2.CreateMessageResponse,
    ]
    """Create a message"""
    ListMessages: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ListMessagesRequest,
        app.app.v1alpha.conversation_pb2.ListMessagesResponse,
    ]
    """List messages"""
    UpdateMessage: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.UpdateMessageRequest,
        app.app.v1alpha.conversation_pb2.UpdateMessageResponse,
    ]
    """Update a message"""
    DeleteMessage: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.DeleteMessageRequest,
        app.app.v1alpha.conversation_pb2.DeleteMessageResponse,
    ]
    """Delete a message"""
    GetPlaygroundConversation: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.GetPlaygroundConversationRequest,
        app.app.v1alpha.app_pb2.GetPlaygroundConversationResponse,
    ]
    """Get Playground Conversation

    get the latest conversation of auth user(e.g. login user and api key user)
    """
    RestartPlaygroundConversation: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.RestartPlaygroundConversationRequest,
        app.app.v1alpha.app_pb2.RestartPlaygroundConversationResponse,
    ]
    """Restart Playground Conversation

    create a new conversation and use the auth user uid as creator uid and auto
    generate a new conversation id on the behalf of auth user.
    """
    Chat: grpc.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ChatRequest,
        app.app.v1alpha.conversation_pb2.ChatResponse,
    ]
    """Chat

    Chat sends a message asynchronously and streams back the response.
    This method is intended for real-time conversation with a chatbot
    and the response needs to be processed incrementally.
    """

class AppPublicServiceAsyncStub:
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.LivenessRequest,
        app.app.v1alpha.app_pb2.LivenessResponse,
    ]
    """Check if the app server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.ReadinessRequest,
        app.app.v1alpha.app_pb2.ReadinessResponse,
    ]
    """Check if the app server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateApp: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.CreateAppRequest,
        app.app.v1alpha.app_pb2.CreateAppResponse,
    ]
    """Create a app"""
    ListApps: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.ListAppsRequest,
        app.app.v1alpha.app_pb2.ListAppsResponse,
    ]
    """List all apps info"""
    UpdateApp: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.UpdateAppRequest,
        app.app.v1alpha.app_pb2.UpdateAppResponse,
    ]
    """Update a app info"""
    DeleteApp: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.DeleteAppRequest,
        app.app.v1alpha.app_pb2.DeleteAppResponse,
    ]
    """Delete a app"""
    CreateConversation: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.CreateConversationRequest,
        app.app.v1alpha.conversation_pb2.CreateConversationResponse,
    ]
    """Create a Conversation"""
    ListConversations: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ListConversationsRequest,
        app.app.v1alpha.conversation_pb2.ListConversationsResponse,
    ]
    """List conversations"""
    UpdateConversation: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.UpdateConversationRequest,
        app.app.v1alpha.conversation_pb2.UpdateConversationResponse,
    ]
    """Update a conversation"""
    DeleteConversation: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.DeleteConversationRequest,
        app.app.v1alpha.conversation_pb2.DeleteConversationResponse,
    ]
    """Delete a conversation"""
    CreateMessage: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.CreateMessageRequest,
        app.app.v1alpha.conversation_pb2.CreateMessageResponse,
    ]
    """Create a message"""
    ListMessages: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ListMessagesRequest,
        app.app.v1alpha.conversation_pb2.ListMessagesResponse,
    ]
    """List messages"""
    UpdateMessage: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.UpdateMessageRequest,
        app.app.v1alpha.conversation_pb2.UpdateMessageResponse,
    ]
    """Update a message"""
    DeleteMessage: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.DeleteMessageRequest,
        app.app.v1alpha.conversation_pb2.DeleteMessageResponse,
    ]
    """Delete a message"""
    GetPlaygroundConversation: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.GetPlaygroundConversationRequest,
        app.app.v1alpha.app_pb2.GetPlaygroundConversationResponse,
    ]
    """Get Playground Conversation

    get the latest conversation of auth user(e.g. login user and api key user)
    """
    RestartPlaygroundConversation: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.app_pb2.RestartPlaygroundConversationRequest,
        app.app.v1alpha.app_pb2.RestartPlaygroundConversationResponse,
    ]
    """Restart Playground Conversation

    create a new conversation and use the auth user uid as creator uid and auto
    generate a new conversation id on the behalf of auth user.
    """
    Chat: grpc.aio.UnaryUnaryMultiCallable[
        app.app.v1alpha.conversation_pb2.ChatRequest,
        app.app.v1alpha.conversation_pb2.ChatResponse,
    ]
    """Chat

    Chat sends a message asynchronously and streams back the response.
    This method is intended for real-time conversation with a chatbot
    and the response needs to be processed incrementally.
    """

class AppPublicServiceServicer(metaclass=abc.ABCMeta):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: app.app.v1alpha.app_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.LivenessResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.LivenessResponse]]:
        """Check if the app server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: app.app.v1alpha.app_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.ReadinessResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.ReadinessResponse]]:
        """Check if the app server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def CreateApp(
        self,
        request: app.app.v1alpha.app_pb2.CreateAppRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.CreateAppResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.CreateAppResponse]]:
        """Create a app"""
    @abc.abstractmethod
    def ListApps(
        self,
        request: app.app.v1alpha.app_pb2.ListAppsRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.ListAppsResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.ListAppsResponse]]:
        """List all apps info"""
    @abc.abstractmethod
    def UpdateApp(
        self,
        request: app.app.v1alpha.app_pb2.UpdateAppRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.UpdateAppResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.UpdateAppResponse]]:
        """Update a app info"""
    @abc.abstractmethod
    def DeleteApp(
        self,
        request: app.app.v1alpha.app_pb2.DeleteAppRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.DeleteAppResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.DeleteAppResponse]]:
        """Delete a app"""
    @abc.abstractmethod
    def CreateConversation(
        self,
        request: app.app.v1alpha.conversation_pb2.CreateConversationRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.CreateConversationResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.CreateConversationResponse]]:
        """Create a Conversation"""
    @abc.abstractmethod
    def ListConversations(
        self,
        request: app.app.v1alpha.conversation_pb2.ListConversationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.ListConversationsResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.ListConversationsResponse]]:
        """List conversations"""
    @abc.abstractmethod
    def UpdateConversation(
        self,
        request: app.app.v1alpha.conversation_pb2.UpdateConversationRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.UpdateConversationResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.UpdateConversationResponse]]:
        """Update a conversation"""
    @abc.abstractmethod
    def DeleteConversation(
        self,
        request: app.app.v1alpha.conversation_pb2.DeleteConversationRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.DeleteConversationResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.DeleteConversationResponse]]:
        """Delete a conversation"""
    @abc.abstractmethod
    def CreateMessage(
        self,
        request: app.app.v1alpha.conversation_pb2.CreateMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.CreateMessageResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.CreateMessageResponse]]:
        """Create a message"""
    @abc.abstractmethod
    def ListMessages(
        self,
        request: app.app.v1alpha.conversation_pb2.ListMessagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.ListMessagesResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.ListMessagesResponse]]:
        """List messages"""
    @abc.abstractmethod
    def UpdateMessage(
        self,
        request: app.app.v1alpha.conversation_pb2.UpdateMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.UpdateMessageResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.UpdateMessageResponse]]:
        """Update a message"""
    @abc.abstractmethod
    def DeleteMessage(
        self,
        request: app.app.v1alpha.conversation_pb2.DeleteMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.DeleteMessageResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.DeleteMessageResponse]]:
        """Delete a message"""
    @abc.abstractmethod
    def GetPlaygroundConversation(
        self,
        request: app.app.v1alpha.app_pb2.GetPlaygroundConversationRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.GetPlaygroundConversationResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.GetPlaygroundConversationResponse]]:
        """Get Playground Conversation

        get the latest conversation of auth user(e.g. login user and api key user)
        """
    @abc.abstractmethod
    def RestartPlaygroundConversation(
        self,
        request: app.app.v1alpha.app_pb2.RestartPlaygroundConversationRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.app_pb2.RestartPlaygroundConversationResponse, collections.abc.Awaitable[app.app.v1alpha.app_pb2.RestartPlaygroundConversationResponse]]:
        """Restart Playground Conversation

        create a new conversation and use the auth user uid as creator uid and auto
        generate a new conversation id on the behalf of auth user.
        """
    @abc.abstractmethod
    def Chat(
        self,
        request: app.app.v1alpha.conversation_pb2.ChatRequest,
        context: _ServicerContext,
    ) -> typing.Union[app.app.v1alpha.conversation_pb2.ChatResponse, collections.abc.Awaitable[app.app.v1alpha.conversation_pb2.ChatResponse]]:
        """Chat

        Chat sends a message asynchronously and streams back the response.
        This method is intended for real-time conversation with a chatbot
        and the response needs to be processed incrementally.
        """

def add_AppPublicServiceServicer_to_server(servicer: AppPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# pylint: disable=no-name-in-module,no-member
import instill.protogen.core.mgmt.v1beta.mgmt_pb2 as mgmt_interface
from instill.clients.app import AppClient
from instill.clients.artifact import ArtifactClient
from instill.clients.mgmt import MgmtClient
from instill.clients.model import ModelClient
from instill.clients.pipeline import PipelineClient
from instill.helpers.const import HOST_URL_PROD
from instill.utils.error_handler import NotServingException
from instill.utils.logger import Logger


class InstillClient:
    def __init__(
        self,
        api_token: str,
        url: str = HOST_URL_PROD,
        secure: bool = True,
        requester_id="",
        async_enabled: bool = False,
    ) -> None:
        self.mgmt = MgmtClient(
            api_token=api_token,
            url=url,
            secure=secure,
            requester_id=requester_id,
            async_enabled=async_enabled,
        )
        if not self.mgmt.is_serving():
            Logger.w("Instill Core is required")
            raise NotServingException

        self.pipeline = PipelineClient(
            api_token=api_token,
            url=url,
            secure=secure,
            lookup_func=self._lookup_namespace_uid,
            requester_id=requester_id,
            async_enabled=async_enabled,
        )
        if not self.pipeline.is_serving():
            Logger.w("Instill VDP is not serving, VDP functionalities will not work")

        self.model = ModelClient(
            api_token=api_token,
            url=url,
            secure=secure,
            lookup_func=self._lookup_namespace_uid,
            requester_id=requester_id,
            async_enabled=async_enabled,
        )
        if not self.model.is_serving():
            Logger.w(
                "Instill Model is not serving, Model functionalities will not work"
            )

        self.artifact = ArtifactClient(
            api_token=api_token,
            url=url,
            secure=secure,
            lookup_func=self._lookup_namespace_uid,
            requester_id=requester_id,
            async_enabled=async_enabled,
        )
        if not self.artifact.is_serving():
            Logger.w(
                "Instill Artifact is not serving, Artifact functionalities will not work"
            )

        self.app = AppClient(
            api_token=api_token,
            url=url,
            secure=secure,
            lookup_func=self._lookup_namespace_uid,
            requester_id=requester_id,
            async_enabled=async_enabled,
        )
        if not self.app.is_serving():
            Logger.w("Instill App is not serving, App functionalities will not work")

    def _lookup_namespace_uid(self, namespace_id: str):
        resp = self.mgmt.check_namespace(namespace_id)
        if resp.type == mgmt_interface.CheckNamespaceAdminResponse.NAMESPACE_USER:
            namespace_uid = self.mgmt.get_user(namespace_id).user.uid
        elif (
            resp.type
            == mgmt_interface.CheckNamespaceAdminResponse.NAMESPACE_ORGANIZATION
        ):
            namespace_uid = self.mgmt.get_organization(namespace_id).organization.uid
        else:
            raise Exception("namespace ID not available")

        return namespace_uid

    def close(self):
        self.mgmt.close()
        self.pipeline.close()
        self.model.close()
        self.artifact.close()
        self.app.close()

    async def async_close(self):
        self.mgmt.async_close()
        self.pipeline.async_close()
        self.model.async_close()
        self.artifact.async_close()
        self.app.async_close()

    def get_mgmt(self) -> MgmtClient:
        return self.mgmt

    def get_artifact(self) -> ArtifactClient:
        return self.artifact

    def get_pipeline(self) -> PipelineClient:
        return self.pipeline

    def get_model(self) -> ModelClient:
        return self.model

    def get_app(self) -> AppClient:
        return self.app


def init_core_client(
    api_token: str,
    requester_id="",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> InstillClient:
    return InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )


def init_artifact_client(
    api_token: str,
    requester_id: str = "",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> ArtifactClient:
    client = InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )
    if not client.get_artifact().is_serving():
        Logger.w(
            "Instill Artifact is not serving, Artifact functionalities will not work"
        )
        raise NotServingException

    return client.get_artifact()


def init_model_client(
    api_token: str,
    requester_id="",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> ModelClient:
    client = InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )
    if not client.get_model().is_serving():
        Logger.w("Instill Model is not serving, Model functionalities will not work")
        raise NotServingException

    return client.get_model()


def init_pipeline_client(
    api_token: str,
    requester_id="",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> PipelineClient:
    client = InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )
    if not client.get_pipeline().is_serving():
        Logger.w("Instill VDP is not serving, VDP functionalities will not work")
        raise NotServingException

    return client.get_pipeline()


def init_mgmt_client(
    api_token: str,
    requester_id="",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> MgmtClient:
    client = InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )
    if not client.get_mgmt().is_serving():
        Logger.w("Instill Core is required")
        raise NotServingException

    return client.get_mgmt()


def init_app_client(
    api_token: str = "",
    requester_id: str = "",
    url: str = HOST_URL_PROD,
    async_enabled: bool = False,
) -> AppClient:
    client = InstillClient(
        api_token=api_token,
        requester_id=requester_id,
        url=url,
        async_enabled=async_enabled,
    )
    if not client.get_app().is_serving():
        Logger.w("Instill App is not serving, App functionalities will not work")
        raise NotServingException

    return client.get_app()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


class PipelinePrivateServiceStub(object):
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPipelinesAdmin = channel.unary_unary(
                '/vdp.pipeline.v1beta.PipelinePrivateService/ListPipelinesAdmin',
                request_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminRequest.SerializeToString,
                response_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminResponse.FromString,
                )
        self.LookUpPipelineAdmin = channel.unary_unary(
                '/vdp.pipeline.v1beta.PipelinePrivateService/LookUpPipelineAdmin',
                request_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminRequest.SerializeToString,
                response_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminResponse.FromString,
                )
        self.ListPipelineReleasesAdmin = channel.unary_unary(
                '/vdp.pipeline.v1beta.PipelinePrivateService/ListPipelineReleasesAdmin',
                request_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminRequest.SerializeToString,
                response_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminResponse.FromString,
                )


class PipelinePrivateServiceServicer(object):
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    def ListPipelinesAdmin(self, request, context):
        """List pipelines (admin only)

        This is a *private* method that allows admin users and internal clients to
        list *all* pipeline resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpPipelineAdmin(self, request, context):
        """Get a pipeline by UID (admin only)

        This is a *private* method that allows admin users to access any pipeline
        resource by its UID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipelineReleasesAdmin(self, request, context):
        """List pipeline releases (admin only)

        This is a *private* method that allows admin users to list *all* pipeline
        releases.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PipelinePrivateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPipelinesAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelinesAdmin,
                    request_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminRequest.FromString,
                    response_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminResponse.SerializeToString,
            ),
            'LookUpPipelineAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpPipelineAdmin,
                    request_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminRequest.FromString,
                    response_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminResponse.SerializeToString,
            ),
            'ListPipelineReleasesAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelineReleasesAdmin,
                    request_deserializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminRequest.FromString,
                    response_serializer=vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vdp.pipeline.v1beta.PipelinePrivateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PipelinePrivateService(object):
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    @staticmethod
    def ListPipelinesAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vdp.pipeline.v1beta.PipelinePrivateService/ListPipelinesAdmin',
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminRequest.SerializeToString,
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelinesAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpPipelineAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vdp.pipeline.v1beta.PipelinePrivateService/LookUpPipelineAdmin',
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminRequest.SerializeToString,
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.LookUpPipelineAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipelineReleasesAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vdp.pipeline.v1beta.PipelinePrivateService/ListPipelineReleasesAdmin',
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminRequest.SerializeToString,
            vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2.ListPipelineReleasesAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app/v1alpha/app_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from app.app.v1alpha import app_pb2 as app_dot_app_dot_v1alpha_dot_app__pb2
from app.app.v1alpha import conversation_pb2 as app_dot_app_dot_v1alpha_dot_conversation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(app/app/v1alpha/app_public_service.proto\x12\x0f\x61pp.app.v1alpha\x1a\x19\x61pp/app/v1alpha/app.proto\x1a\"app/app/v1alpha/conversation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd0\x19\n\x10\x41ppPublicService\x12\x93\x01\n\x08Liveness\x12 .app.app.v1alpha.LivenessRequest\x1a!.app.app.v1alpha.LivenessResponse\"B\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12\x13/v1alpha/__livenessZ\x15\x12\x13/v1alpha/health/app\x12\x96\x01\n\tReadiness\x12!.app.app.v1alpha.ReadinessRequest\x1a\".app.app.v1alpha.ReadinessResponse\"B\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12\x14/v1alpha/__readinessZ\x14\x12\x12/v1alpha/ready/app\x12\x8e\x01\n\tCreateApp\x12!.app.app.v1alpha.CreateAppRequest\x1a\".app.app.v1alpha.CreateAppResponse\":\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02,\"\'/v1alpha/namespaces/{namespace_id}/apps:\x01*\x12\x88\x01\n\x08ListApps\x12 .app.app.v1alpha.ListAppsRequest\x1a!.app.app.v1alpha.ListAppsResponse\"7\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02)\x12\'/v1alpha/namespaces/{namespace_id}/apps\x12\x97\x01\n\tUpdateApp\x12!.app.app.v1alpha.UpdateAppRequest\x1a\".app.app.v1alpha.UpdateAppResponse\"C\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02\x35\x1a\x30/v1alpha/namespaces/{namespace_id}/apps/{app_id}:\x01*\x12\x94\x01\n\tDeleteApp\x12!.app.app.v1alpha.DeleteAppRequest\x1a\".app.app.v1alpha.DeleteAppResponse\"@\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02\x32*0/v1alpha/namespaces/{namespace_id}/apps/{app_id}\x12\xc9\x01\n\x12\x43reateConversation\x12*.app.app.v1alpha.CreateConversationRequest\x1a+.app.app.v1alpha.CreateConversationResponse\"Z\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02\x43\">/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations:\x01*\x12\xc3\x01\n\x11ListConversations\x12).app.app.v1alpha.ListConversationsRequest\x1a*.app.app.v1alpha.ListConversationsResponse\"W\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations\x12\xdb\x01\n\x12UpdateConversation\x12*.app.app.v1alpha.UpdateConversationRequest\x1a+.app.app.v1alpha.UpdateConversationResponse\"l\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02U\x1aP/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}:\x01*\x12\xd8\x01\n\x12\x44\x65leteConversation\x12*.app.app.v1alpha.DeleteConversationRequest\x1a+.app.app.v1alpha.DeleteConversationResponse\"i\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02R*P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}\x12\xd0\x01\n\rCreateMessage\x12%.app.app.v1alpha.CreateMessageRequest\x1a&.app.app.v1alpha.CreateMessageResponse\"p\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02^\"Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages:\x01*\x12\xca\x01\n\x0cListMessages\x12$.app.app.v1alpha.ListMessagesRequest\x1a%.app.app.v1alpha.ListMessagesResponse\"m\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02[\x12Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages\x12\xde\x01\n\rUpdateMessage\x12%.app.app.v1alpha.UpdateMessageRequest\x1a&.app.app.v1alpha.UpdateMessageResponse\"~\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02l\x1ag/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}:\x01*\x12\xdb\x01\n\rDeleteMessage\x12%.app.app.v1alpha.DeleteMessageRequest\x1a&.app.app.v1alpha.DeleteMessageResponse\"{\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02i*g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}\x12\xf0\x01\n\x19GetPlaygroundConversation\x12\x31.app.app.v1alpha.GetPlaygroundConversationRequest\x1a\x32.app.app.v1alpha.GetPlaygroundConversationResponse\"l\x92\x41\x0c\n\nPlayground\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/conversation\x12\xf7\x01\n\x1dRestartPlaygroundConversation\x12\x35.app.app.v1alpha.RestartPlaygroundConversationRequest\x1a\x36.app.app.v1alpha.RestartPlaygroundConversationResponse\"g\x92\x41\x0c\n\nPlayground\x82\xd3\xe4\x93\x02R\"P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/restart\x12\x8d\x01\n\x04\x43hat\x12\x1c.app.app.v1alpha.ChatRequest\x1a\x1d.app.app.v1alpha.ChatResponse\"H\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02:\"5/v1alpha/namespaces/{namespace_id}/apps/{app_id}/chat:\x01*\x1a\x19\x92\x41\x16\x12\x14Public App endpointsB\xc8\x01\n\x13\x63om.app.app.v1alphaB\x15\x41ppPublicServiceProtoP\x01Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x0f\x41pp.App.V1alpha\xca\x02\x0f\x41pp\\App\\V1alpha\xe2\x02\x1b\x41pp\\App\\V1alpha\\GPBMetadata\xea\x02\x11\x41pp::App::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app.v1alpha.app_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.app.app.v1alphaB\025AppPublicServiceProtoP\001Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\242\002\003AAX\252\002\017App.App.V1alpha\312\002\017App\\App\\V1alpha\342\002\033App\\App\\V1alpha\\GPBMetadata\352\002\021App::App::V1alpha'
  _APPPUBLICSERVICE._options = None
  _APPPUBLICSERVICE._serialized_options = b'\222A\026\022\024Public App endpoints'
  _APPPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _APPPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022\023/v1alpha/__livenessZ\025\022\023/v1alpha/health/app'
  _APPPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _APPPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022\024/v1alpha/__readinessZ\024\022\022/v1alpha/ready/app'
  _APPPUBLICSERVICE.methods_by_name['CreateApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002,\"\'/v1alpha/namespaces/{namespace_id}/apps:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListApps']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListApps']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002)\022\'/v1alpha/namespaces/{namespace_id}/apps'
  _APPPUBLICSERVICE.methods_by_name['UpdateApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\0025\0320/v1alpha/namespaces/{namespace_id}/apps/{app_id}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\0022*0/v1alpha/namespaces/{namespace_id}/apps/{app_id}'
  _APPPUBLICSERVICE.methods_by_name['CreateConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002C\">/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListConversations']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListConversations']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations'
  _APPPUBLICSERVICE.methods_by_name['UpdateConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002U\032P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002R*P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}'
  _APPPUBLICSERVICE.methods_by_name['CreateMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002^\"Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListMessages']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListMessages']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002[\022Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages'
  _APPPUBLICSERVICE.methods_by_name['UpdateMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002l\032g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002i*g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}'
  _APPPUBLICSERVICE.methods_by_name['GetPlaygroundConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['GetPlaygroundConversation']._serialized_options = b'\222A\014\n\nPlayground\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/conversation'
  _APPPUBLICSERVICE.methods_by_name['RestartPlaygroundConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['RestartPlaygroundConversation']._serialized_options = b'\222A\014\n\nPlayground\202\323\344\223\002R\"P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/restart'
  _APPPUBLICSERVICE.methods_by_name['Chat']._options = None
  _APPPUBLICSERVICE.methods_by_name['Chat']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002:\"5/v1alpha/namespaces/{namespace_id}/apps/{app_id}/chat:\001*'
  _globals['_APPPUBLICSERVICE']._serialized_start=232
  _globals['_APPPUBLICSERVICE']._serialized_end=3512
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    """Unspecified, equivalent to VIEWER."""
    ROLE_VIEWER: _Role.ValueType  # 1
    """Viewers can see the resource properties."""
    ROLE_EXECUTOR: _Role.ValueType  # 2
    """Executors can execute the resource (e.g. trigger a pipeline)."""

class Role(_Role, metaclass=_RoleEnumTypeWrapper):
    """Role describes the permissions a user has over a resource."""

ROLE_UNSPECIFIED: Role.ValueType  # 0
"""Unspecified, equivalent to VIEWER."""
ROLE_VIEWER: Role.ValueType  # 1
"""Viewers can see the resource properties."""
ROLE_EXECUTOR: Role.ValueType  # 2
"""Executors can execute the resource (e.g. trigger a pipeline)."""
global___Role = Role

class _ComponentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ComponentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ComponentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMPONENT_TYPE_UNSPECIFIED: _ComponentType.ValueType  # 0
    """Unspecified."""
    COMPONENT_TYPE_AI: _ComponentType.ValueType  # 1
    """Connect with an AI model."""
    COMPONENT_TYPE_DATA: _ComponentType.ValueType  # 2
    """Connect with a remote data source."""
    COMPONENT_TYPE_OPERATOR: _ComponentType.ValueType  # 4
    """Manipulate data."""
    COMPONENT_TYPE_APPLICATION: _ComponentType.ValueType  # 5
    """Connect with an external application."""
    COMPONENT_TYPE_GENERIC: _ComponentType.ValueType  # 6
    """Generic."""

class ComponentType(_ComponentType, metaclass=_ComponentTypeEnumTypeWrapper):
    """ComponentType defines the component type based on its task features."""

COMPONENT_TYPE_UNSPECIFIED: ComponentType.ValueType  # 0
"""Unspecified."""
COMPONENT_TYPE_AI: ComponentType.ValueType  # 1
"""Connect with an AI model."""
COMPONENT_TYPE_DATA: ComponentType.ValueType  # 2
"""Connect with a remote data source."""
COMPONENT_TYPE_OPERATOR: ComponentType.ValueType  # 4
"""Manipulate data."""
COMPONENT_TYPE_APPLICATION: ComponentType.ValueType  # 5
"""Connect with an external application."""
COMPONENT_TYPE_GENERIC: ComponentType.ValueType  # 6
"""Generic."""
global___ComponentType = ComponentType

class _View:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_View.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VIEW_UNSPECIFIED: _View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: _View.ValueType  # 1
    """Default view."""
    VIEW_FULL: _View.ValueType  # 2
    """Full representation."""

class View(_View, metaclass=_ViewEnumTypeWrapper):
    """View defines how a resource is presented. Most resources can share this view
    definition, the particular meaning of each value should be defined in the
    resource itself. Certain resources might have their own View definition if
    they need to implement more than 2 (basic / full) views.
    """

VIEW_UNSPECIFIED: View.ValueType  # 0
"""Unspecified, equivalent to BASIC."""
VIEW_BASIC: View.ValueType  # 1
"""Default view."""
VIEW_FULL: View.ValueType  # 2
"""Full representation."""
global___View = View

@typing_extensions.final
class Sharing(google.protobuf.message.Message):
    """Sharing contains the information to share a resource with other users.

    For more information, see [Share Pipelines](https://www.instill.tech/docs/vdp/share).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class User(google.protobuf.message.Message):
        """Describes the sharing configuration with a given user."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """Defines whether the sharing option with this user is enabled."""
        role: global___Role.ValueType
        """Defines the role the user will have over the resource."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            role: global___Role.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "role", b"role"]) -> None: ...

    @typing_extensions.final
    class ShareCode(google.protobuf.message.Message):
        """ShareCode describes a sharing configuration through a link."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USER_FIELD_NUMBER: builtins.int
        CODE_FIELD_NUMBER: builtins.int
        ENABLED_FIELD_NUMBER: builtins.int
        ROLE_FIELD_NUMBER: builtins.int
        user: builtins.str
        """Defines which users will be able to access the resource through the
        code. This is a pattern that will be checked against user names.

        For now, the only accepted value is `*/*`.
        """
        code: builtins.str
        """The public URL that allows users to access the resource."""
        enabled: builtins.bool
        """Defines whether the sharing option via link is enabled."""
        role: global___Role.ValueType
        """Defines the role users will have over the resource."""
        def __init__(
            self,
            *,
            user: builtins.str = ...,
            code: builtins.str = ...,
            enabled: builtins.bool = ...,
            role: global___Role.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "enabled", b"enabled", "role", b"role", "user", b"user"]) -> None: ...

    @typing_extensions.final
    class UsersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Sharing.User: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Sharing.User | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERS_FIELD_NUMBER: builtins.int
    SHARE_CODE_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Sharing.User]:
        """Defines sharing rules for a set of user resource names.

        Each key in this object should contain a pattern that can be matched
        against user names.

        Each value is a user sharing configuration.

        **NOTE**: For now, the only accepted key is `*/*`.
        """
    @property
    def share_code(self) -> global___Sharing.ShareCode:
        """Defines the configuration to share a resource via link."""
    def __init__(
        self,
        *,
        users: collections.abc.Mapping[builtins.str, global___Sharing.User] | None = ...,
        share_code: global___Sharing.ShareCode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_code", b"share_code"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_code", b"share_code", "users", b"users"]) -> None: ...

global___Sharing = Sharing

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    """Permission defines how a pipeline can be used."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_TRIGGER_FIELD_NUMBER: builtins.int
    CAN_RELEASE_FIELD_NUMBER: builtins.int
    can_edit: builtins.bool
    """Defines whether the pipeline can be modified."""
    can_trigger: builtins.bool
    """Defines whether the pipeline can be executed."""
    can_release: builtins.bool
    """Defines whether the pipeline can be released."""
    def __init__(
        self,
        *,
        can_edit: builtins.bool = ...,
        can_trigger: builtins.bool = ...,
        can_release: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_edit", b"can_edit", "can_release", b"can_release", "can_trigger", b"can_trigger"]) -> None: ...

global___Permission = Permission

@typing_extensions.final
class CheckNameRequest(google.protobuf.message.Message):
    """CheckNameRequest represents a request to verify if a name is
    available.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the resource to be checked. For the moment, only pipeline and
    connector names can be checked. The following formats are accepted:
    - `users/{user.id}/pipelines/{pipeline.id}`
    - `users/{user.id}/connectors/{connector.id}`
    - `organizations/{organization.id}/pipelines/{pipeline.id}`
    - `organizations/{organization.id}/connectors/{connector.id}`
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CheckNameRequest = CheckNameRequest

@typing_extensions.final
class CheckNameResponse(google.protobuf.message.Message):
    """CheckNameResponse contains the availability of a resource name."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Name:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NameEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CheckNameResponse._Name.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NAME_UNSPECIFIED: CheckNameResponse._Name.ValueType  # 0
        """Unspecified."""
        NAME_AVAILABLE: CheckNameResponse._Name.ValueType  # 1
        """Available."""
        NAME_UNAVAILABLE: CheckNameResponse._Name.ValueType  # 2
        """Unavailable."""

    class Name(_Name, metaclass=_NameEnumTypeWrapper):
        """Name defines the availability of a resource name."""

    NAME_UNSPECIFIED: CheckNameResponse.Name.ValueType  # 0
    """Unspecified."""
    NAME_AVAILABLE: CheckNameResponse.Name.ValueType  # 1
    """Available."""
    NAME_UNAVAILABLE: CheckNameResponse.Name.ValueType  # 2
    """Unavailable."""

    AVAILABILITY_FIELD_NUMBER: builtins.int
    availability: global___CheckNameResponse.Name.ValueType
    """The availability of the requested name."""
    def __init__(
        self,
        *,
        availability: global___CheckNameResponse.Name.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability", b"availability"]) -> None: ...

global___CheckNameResponse = CheckNameResponse

@typing_extensions.final
class ComponentTask(google.protobuf.message.Message):
    """ComponentTask contains information about a task that a component can
    perform.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The task name, e.g. `TASK_TEXT_GENERATION`."""
    title: builtins.str
    """Title is the task name in a human-friendly format."""
    description: builtins.str
    """Description contains information about the task."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "title", b"title"]) -> None: ...

global___ComponentTask = ComponentTask



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from app.app.v1alpha import app_pb2 as app_dot_app_dot_v1alpha_dot_app__pb2
from app.app.v1alpha import conversation_pb2 as app_dot_app_dot_v1alpha_dot_conversation__pb2


class AppPublicServiceStub(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Liveness',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Readiness',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.FromString,
                )
        self.CreateApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.FromString,
                )
        self.ListApps = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListApps',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.FromString,
                )
        self.UpdateApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.FromString,
                )
        self.DeleteApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.FromString,
                )
        self.CreateConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.FromString,
                )
        self.ListConversations = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListConversations',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.FromString,
                )
        self.UpdateConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.FromString,
                )
        self.DeleteConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.FromString,
                )
        self.CreateMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.FromString,
                )
        self.ListMessages = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListMessages',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.FromString,
                )
        self.UpdateMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.FromString,
                )
        self.DeleteMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.FromString,
                )
        self.GetPlaygroundConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/GetPlaygroundConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.FromString,
                )
        self.RestartPlaygroundConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/RestartPlaygroundConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.FromString,
                )
        self.Chat = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Chat',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.FromString,
                )


class AppPublicServiceServicer(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    def Liveness(self, request, context):
        """Check if the app server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the app server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApp(self, request, context):
        """Create a app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApps(self, request, context):
        """List all apps info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateApp(self, request, context):
        """Update a app info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApp(self, request, context):
        """Delete a app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConversation(self, request, context):
        """Create a Conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConversations(self, request, context):
        """List conversations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConversation(self, request, context):
        """Update a conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConversation(self, request, context):
        """Delete a conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMessage(self, request, context):
        """Create a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMessages(self, request, context):
        """List messages
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMessage(self, request, context):
        """Update a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessage(self, request, context):
        """Delete a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlaygroundConversation(self, request, context):
        """Get Playground Conversation

        get the latest conversation of auth user(e.g. login user and api key user)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartPlaygroundConversation(self, request, context):
        """Restart Playground Conversation

        create a new conversation and use the auth user uid as creator uid and auto
        generate a new conversation id on the behalf of auth user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Chat(self, request, context):
        """Chat

        Chat sends a message asynchronously and streams back the response.
        This method is intended for real-time conversation with a chatbot
        and the response needs to be processed incrementally.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AppPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.SerializeToString,
            ),
            'ListApps': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApps,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.SerializeToString,
            ),
            'UpdateApp': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.SerializeToString,
            ),
            'DeleteApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.SerializeToString,
            ),
            'CreateConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.SerializeToString,
            ),
            'ListConversations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConversations,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.SerializeToString,
            ),
            'UpdateConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.SerializeToString,
            ),
            'DeleteConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.SerializeToString,
            ),
            'CreateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.SerializeToString,
            ),
            'ListMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMessages,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.SerializeToString,
            ),
            'UpdateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.SerializeToString,
            ),
            'DeleteMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.SerializeToString,
            ),
            'GetPlaygroundConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlaygroundConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.SerializeToString,
            ),
            'RestartPlaygroundConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartPlaygroundConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.SerializeToString,
            ),
            'Chat': grpc.unary_unary_rpc_method_handler(
                    servicer.Chat,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'app.app.v1alpha.AppPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AppPublicService(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Liveness',
            app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Readiness',
            app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListApps',
            app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConversations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListConversations',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListMessages',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPlaygroundConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/GetPlaygroundConversation',
            app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartPlaygroundConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/RestartPlaygroundConversation',
            app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Chat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Chat',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/usage/v1beta/usage_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.usage.v1beta import usage_pb2 as core_dot_usage_dot_v1beta_dot_usage__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%core/usage/v1beta/usage_service.proto\x12\x11\x63ore.usage.v1beta\x1a\x1d\x63ore/usage/v1beta/usage.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto2\xce\x04\n\x0cUsageService\x12\x87\x01\n\x08Liveness\x12\".core.usage.v1beta.LivenessRequest\x1a#.core.usage.v1beta.LivenessResponse\"2\x82\xd3\xe4\x93\x02,\x12\x12/v1beta/__livenessZ\x16\x12\x14/v1beta/health/usage\x12s\n\tReadiness\x12#.core.usage.v1beta.ReadinessRequest\x1a$.core.usage.v1beta.ReadinessResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1beta/__readiness\x12\x85\x01\n\rCreateSession\x12\'.core.usage.v1beta.CreateSessionRequest\x1a(.core.usage.v1beta.CreateSessionResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x10/v1beta/sessions:\x07session\x12\x8f\x01\n\x11SendSessionReport\x12+.core.usage.v1beta.SendSessionReportRequest\x1a,.core.usage.v1beta.SendSessionReportResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x0f/v1beta/reports:\x06report\x1a%\xca\x41\x12usage.instill.tech\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xd1\x01\n\x15\x63om.core.usage.v1betaB\x11UsageServiceProtoP\x01Z?github.com/instill-ai/protogen-go/core/usage/v1beta;usagev1beta\xa2\x02\x03\x43UX\xaa\x02\x11\x43ore.Usage.V1beta\xca\x02\x11\x43ore\\Usage\\V1beta\xe2\x02\x1d\x43ore\\Usage\\V1beta\\GPBMetadata\xea\x02\x13\x43ore::Usage::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.usage.v1beta.usage_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.core.usage.v1betaB\021UsageServiceProtoP\001Z?github.com/instill-ai/protogen-go/core/usage/v1beta;usagev1beta\242\002\003CUX\252\002\021Core.Usage.V1beta\312\002\021Core\\Usage\\V1beta\342\002\035Core\\Usage\\V1beta\\GPBMetadata\352\002\023Core::Usage::V1beta'
  _USAGESERVICE._options = None
  _USAGESERVICE._serialized_options = b'\312A\022usage.instill.tech\372\322\344\223\002\n\022\010INTERNAL'
  _USAGESERVICE.methods_by_name['Liveness']._options = None
  _USAGESERVICE.methods_by_name['Liveness']._serialized_options = b'\202\323\344\223\002,\022\022/v1beta/__livenessZ\026\022\024/v1beta/health/usage'
  _USAGESERVICE.methods_by_name['Readiness']._options = None
  _USAGESERVICE.methods_by_name['Readiness']._serialized_options = b'\202\323\344\223\002\025\022\023/v1beta/__readiness'
  _USAGESERVICE.methods_by_name['CreateSession']._options = None
  _USAGESERVICE.methods_by_name['CreateSession']._serialized_options = b'\202\323\344\223\002\033\"\020/v1beta/sessions:\007session'
  _USAGESERVICE.methods_by_name['SendSessionReport']._options = None
  _USAGESERVICE.methods_by_name['SendSessionReport']._serialized_options = b'\202\323\344\223\002\031\"\017/v1beta/reports:\006report'
  _globals['_USAGESERVICE']._serialized_start=176
  _globals['_USAGESERVICE']._serialized_end=766
# @@protoc_insertion_point(module_scope)
